| marshal | R Documentation |
Marshalling of R objects
marshal(...)
unmarshal(...)
... |
The object to be marshalled, or unmarshalled, followed by additional arguments passed to the specific S3 method. |
marshal() returns a marshalled object, which is a list with
components:
marshalled: marshalled version of the original object
unmarshal: function that takes the marshalled object as
input and returns an unmarshalled version of the original object.
unmarshal() returns an unmarshalled version of the original object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.