View source: R/marshal.default.R
| marshal.default | R Documentation |
Marshalling of an R objects
## Default S3 method:
marshal(x, ...)
x |
An R object. |
... |
Not used. |
This is the default, fallback method for marshalling of an
R object. It assumes that the object do not need specific
marshalling, but can be serialized as-is. All this default
method does is wrapping the original object up in a
marshalled object, so that the original object can be
recovered via unmarshalled().
A marshalled object as described in marshal().
x <- data.frame(a = 1:3, b = letters[1:3])
x_ <- marshal(x)
x2 <- unmarshal(x_)
stopifnot(identical(x2, x))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.