| marshallable | R Documentation |
Check if R object can be marshalled
marshallable(...)
... |
The object to be checked, followed by additional arguments passed to the specific S3 method. |
TRUE if the object can be marshalled,
FALSE if it cannot be marshalled, and
NA if it is not known whether the object can be marshalled.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.